/*
 * Copyright 2011-2012 BitMeister Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package jp.bitmeister.asn1.annotation;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

import jp.bitmeister.asn1.type.ASN1Module;

/**
 * Indicates an ASN.1 module that a type is defined.
 * 
 * <p>
 * If this annotation is present on a sub-class of {@code ASN1Type}, it
 * indicates a {@code Class} object of a sub-class of {@code ASN1Module} that
 * represents an ASN.1 module that the type is included in.
 * </p>
 * 
 * @author WATANABE, Jun. <jwat at bitmeister.jp>
 * 
 * @see ASN1Module
 */
@Target(ElementType.TYPE)
@Retention(RetentionPolicy.RUNTIME)
public @interface ASN1ModuleRef {

	/**
	 * Indicates an ASN.1 module that the type is defined.
	 * 
	 * @return The {@code Class} object of an ASN.1 module.
	 */
	public Class<? extends ASN1Module> value();

}
